@@ -217,6 +217,8 @@ typedef struct
 
   gboolean block_close_response;
   gboolean is_short;
+
+  GBinding *child_visible_binding;
 } AdwAlertDialogPrivate;
 
 static void adw_alert_dialog_buildable_init (GtkBuildableIface *iface);
@@ -979,10 +981,13 @@ adw_alert_dialog_class_init (AdwAlertDialogClass *klass)
    *
    * The response ID of the default response.
    *
-   * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+   * The button corresponding to this response will be set as the default widget
+   * of the dialog.
    *
-   * If set to `NULL` or a non-existent response ID, pressing <kbd>Enter</kbd>
-   * will do nothing.
+   * If not set, the default widget will not be set, and the last added response
+   * will be focused by default.
+   *
+   * See [property@Dialog:default-widget].
    *
    * Since: 1.5
    */
@@ -1840,17 +1845,27 @@ adw_alert_dialog_set_extra_child (AdwAlertDialog *self,
   g_return_if_fail (ADW_IS_ALERT_DIALOG (self));
   g_return_if_fail (child == NULL || GTK_IS_WIDGET (child));
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   priv = adw_alert_dialog_get_instance_private (self);
 
   if (child == priv->child)
     return;
 
+  if (child)
+    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
+
+  g_clear_pointer (&priv->child_visible_binding, g_binding_unbind);
+
   priv->child = child;
   adw_bin_set_child (ADW_BIN (priv->child_bin), child);
-  gtk_widget_set_visible (priv->child_bin, child != NULL);
+
+  if (child) {
+    priv->child_visible_binding =
+      g_object_bind_property (child, "visible",
+                              priv->child_bin, "visible",
+                              G_BINDING_SYNC_CREATE);
+  } else {
+    gtk_widget_set_visible (priv->child_bin, FALSE);
+  }
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_EXTRA_CHILD]);
 }
@@ -2316,10 +2331,13 @@ adw_alert_dialog_get_default_response (AdwAlertDialog *self)
  *
  * Sets the ID of the default response of @self.
  *
- * If set, pressing <kbd>Enter</kbd> will activate the corresponding button.
+ * The button corresponding to this response will be set as the default widget
+ * of @self.
  *
- * If set to `NULL` or to a non-existent response ID, pressing <kbd>Enter</kbd>
- * will do nothing.
+ * If not set, the default widget will not be set, and the last added response
+ * will be focused by default.
+ *
+ * See [property@Dialog:default-widget].
  *
  * Since: 1.5
  */
